@@ -5,6 +5,7 @@ import os
 import re
 
 import sphinx.environment
+from sphinx.errors import ExtensionError
 import sphinx.util
 from sphinx.util.console import bold
 import sphinx.util.docstrings
@@ -286,6 +287,9 @@ class PythonSphinxMapper(SphinxMapperBase):
         shortened, relative path the package/module
         """
         dir_root_files = list(self._find_files(patterns, dirs, ignore))
+        if not dir_root_files:
+            raise ExtensionError(f"No source files found in: {','.join(dirs)}")
+
         if not self._need_to_load(dir_root_files):
             LOGGER.debug(
                 "[AutoAPI] Skipping read stage because source files have not changed."
@@ -390,11 +394,18 @@ class PythonSphinxMapper(SphinxMapperBase):
             # or type annotations (eg classes with inheritance),
             # so do this after all children have been created.
             lines = obj.docstring.splitlines()
-            lines.append("")  # Add back the trailing newline that .splitlines removes
-            if lines and "autodoc-process-docstring" in self.app.events.events:
-                self.app.emit(
-                    "autodoc-process-docstring", cls.type, obj.name, None, None, lines
-                )
+            if lines:
+                # Add back the trailing newline that .splitlines removes
+                lines.append("")
+                if "autodoc-process-docstring" in self.app.events.events:
+                    self.app.emit(
+                        "autodoc-process-docstring",
+                        cls.type,
+                        obj.name,
+                        None,
+                        None,
+                        lines,
+                    )
             obj.docstring = "\n".join(lines)
             self._record_typehints(obj)
 
